@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php,v 1.79 2006/09/24 14:19:50 gruberroland Exp $
+$Id: confmain.php,v 1.85 2007/03/05 17:05:38 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003 - 2006  Roland Gruber
+  Copyright (C) 2003 - 2007  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ $Id: confmain.php,v 1.79 2006/09/24 14:19:50 gruberroland Exp $
 *
 * @package configuration
 * @author Roland Gruber
+* @author Thomas Manninger
 */
 
 
@@ -194,7 +195,9 @@ echo ("<fieldset><legend><b>" . _("Account types and modules") . "</b></legend>"
 // Account modules
 $types = $conf->get_ActiveTypes();
 for ($i = 0; $i < sizeof($types); $i++) {
-	echo "<b>" . getTypeAlias($types[$i]) . ": </b>" . implode(", ", $conf->get_AccountModules($types[$i])) . "<br>\n";
+	$moduleNames = $conf->get_AccountModules($types[$i]);
+	for ($m = 0; $m < sizeof($moduleNames); $m++) $moduleNames[$m] = getModuleAlias($moduleNames[$m], $types[$i]);
+	echo "<b>" . getTypeAlias($types[$i]) . ": </b>" . implode(", ", $moduleNames) . "<br>\n";
 }
 echo "<br>\n";
 echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"edittypes\" value=\"" . _("Edit account types") . "\">&nbsp;&nbsp;";
@@ -223,8 +226,6 @@ for ($m = 0; $m < sizeof($types); $m++) {
 $options = getConfigOptions($scopes);
 // get current setting
 $old_options = $conf->get_moduleSettings();
-// get module descriptions
-$moduleDescriptions = getConfigDescriptions();
 
 
 // display module boxes
@@ -233,7 +234,7 @@ $_SESSION['conf_types'] = array();
 for ($i = 0; $i < sizeof($modules); $i++) {
 	if (sizeof($options[$modules[$i]]) < 1) continue;
 	echo "<fieldset>\n";
-	echo "<legend><b>" . $moduleDescriptions['legend'][$modules[$i]] . "</b></legend>\n";
+	echo "<legend><b>" . getModuleAlias($modules[$i], "none") . "</b></legend>\n";
 	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, $tabindexLink, 'config');
 	$_SESSION['conf_types'] = array_merge($configTypes, $_SESSION['conf_types']);
 	echo "</fieldset>\n";
@@ -317,11 +318,11 @@ echo ("<fieldset><legend><b>" . _("Script settings") . "</b></legend>\n");
 echo ("<table border=0>\n");
 
 echo ("<tr><td align=\"right\"><b>".
-	_("Server of external script") . ": </b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"scriptserver\" value=\"" . $conf->get_scriptServer() . "\"></td>\n");
+	_("Server list") . ": </b></td>".
+	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"scriptservers\" value=\"" . $conf->get_scriptServers(false) . "\"></td>\n");
 $tabindex++;
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=211\" target=\"lamhelp\">";
+echo "<a href=\"../help.php?HelpNumber=218\" target=\"lamhelp\">";
 echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
 echo "</a>\n";
 echo "</td></tr>\n";
@@ -334,6 +335,51 @@ echo "<a href=\"../help.php?HelpNumber=210\" target=\"lamhelp\">";
 echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
 echo "</a>\n";
 echo "</td></tr>\n";
+echo "<tr><td align=\"right\"><b>". _("Rights for the home directory") . ": </b></td>\n";
+$owr = "";
+$oww = "";
+$owe = "";
+$grr = "";
+$grw = "";
+$gre = "";
+$otr = "";
+$otw = "";
+$ote = "";
+$chmod = $conf->get_scriptRights();
+if (checkChmod("read","owner", $chmod)) $owr = 'checked';
+if (checkChmod("write","owner", $chmod)) $oww = 'checked';
+if (checkChmod("execute","owner", $chmod)) $owe = 'checked';
+if (checkChmod("read","group", $chmod)) $grr = 'checked';
+if (checkChmod("write","group", $chmod)) $grw = 'checked';
+if (checkChmod("execute","group", $chmod)) $gre = 'checked';
+if (checkChmod("read","other", $chmod)) $otr = 'checked';
+if (checkChmod("write","other", $chmod)) $otw = 'checked';
+if (checkChmod("execute","other", $chmod)) $ote = 'checked';
+
+echo "<td align=\"center\">\n";
+	echo "<table width=\"280\"><tr align=\"center\">\n";
+	echo "<td width=\"70\"></td><th width=\"70\">" . _("Read") . "</th>\n";
+	echo "<th width=\"70\">" . _("Write") . "</th>\n";
+	echo "<th width=\"70\">"._("Execute")."</th></tr>\n";
+	echo "<tr align=\"center\"><th align=\"left\">"._("Owner")."</th>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_owr\" " . $owr . "></td>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_oww\" " . $oww . "></td>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_owe\" " . $owe . "></td></tr>\n";
+	echo "<tr align=\"center\"><th align=\"left\">"._("Group")."</th>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_grr\" " . $grr . "></td>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_grw\" " . $grw . "></td>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_gre\" " . $gre . "></td></tr>\n";
+	echo "<tr align=\"center\"><th align=\"left\">"._("Other")."</th>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_otr\" " . $otr . "></td>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_otw\" " . $otw . "></td>\n";
+	echo "<td><input type=\"checkbox\" name=\"chmod_ote\" " . $ote . "></td>\n";
+	echo "</tr></table>";
+	$tabindex++;
+echo "<td>";
+echo "<a href=\"../help.php?HelpNumber=219\" target=\"lamhelp\">";
+echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+echo "</a>\n";
+echo "</td></tr>\n";
 
 echo ("</table>\n");
 echo ("</fieldset>\n");
@@ -344,9 +390,10 @@ echo ("<p></p>\n");
 echo ("<fieldset><legend><b>" . _("Security settings") . "</b></legend>\n");
 echo ("<table border=0>\n");
 // admin list
+$adminText = implode("\n", explode(";", $conf->get_Adminstring()));
 echo ("<tr><td align=\"right\"><b>".
 	_("List of valid users") . " *: </b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"admins\" value=\"" . $conf->get_Adminstring() . "\"></td>\n");
+	"<td><textarea tabindex=\"$tabindex\" size=50 type=\"text\" name=\"admins\" cols=75 rows=5>" . $adminText . "</textarea></td>\n");
 echo "<td>";
 echo "<a href=\"../help.php?HelpNumber=207\" target=\"lamhelp\">";
 echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
@@ -427,7 +474,14 @@ function saveSettings() {
 	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
 	}
-	if (!$conf->set_Adminstring($_POST['admins'])) {
+	$adminText = $_POST['admins'];
+	$adminText = explode("\n", $adminText);
+	$adminTextNew = array();
+	for ($i = 0; $i < sizeof($adminText); $i++) {
+		if (trim($adminText[$i]) == "") continue;
+		$adminTextNew[] = trim($adminText[$i]);
+	}
+	if (!$conf->set_Adminstring(implode(";", $adminTextNew))) {
 		$errors[] = array("ERROR", _("List of admin users is empty or invalid!"));
 	}
 	if (!$conf->set_Suffix("tree", $_POST['sufftree'])) {
@@ -442,9 +496,25 @@ function saveSettings() {
 	if (!$conf->set_scriptpath($_POST['scriptpath'])) {
 		$errors[] = array("ERROR", _("Script path is invalid!"));
 	}
-	if (!$conf->set_scriptserver($_POST['scriptserver'])) {
+	if (!$conf->set_scriptservers($_POST['scriptservers'])) {
 		$errors[] = array("ERROR", _("Script server is invalid!"));
 	}
+	$chmodOwner = 0;
+	$chmodGroup = 0;
+	$chmodOther = 0;
+	if ($_POST['chmod_owr'] == 'on') $chmodOwner += 4;
+	if ($_POST['chmod_oww'] == 'on') $chmodOwner += 2;
+	if ($_POST['chmod_owe'] == 'on') $chmodOwner += 1;
+	if ($_POST['chmod_grr'] == 'on') $chmodGroup += 4;
+	if ($_POST['chmod_grw'] == 'on') $chmodGroup += 2;
+	if ($_POST['chmod_gre'] == 'on') $chmodGroup += 1;
+	if ($_POST['chmod_otr'] == 'on') $chmodOther += 4;
+	if ($_POST['chmod_otw'] == 'on') $chmodOther += 2;
+	if ($_POST['chmod_ote'] == 'on') $chmodOther += 1;
+	$chmod = $chmodOwner . $chmodGroup . $chmodOther;
+	if (!$conf->set_scriptrights($chmod)) {
+		$errors[] = array("ERROR", _("Script rights are invalid!"));
+	}
 	// check if password was changed
 	if (isset($_POST['passwd1']) && ($_POST['passwd1'] != '')) {
 		if ($_POST['passwd1'] != $_POST['passwd2']) {
