@@ -1,9 +1,10 @@
 <?php
 /*
-	$Id: delete.php,v 1.58 2006/10/22 07:44:01 gruberroland Exp $
+	$Id: delete.php,v 1.60 2007/02/25 13:51:40 gruberroland Exp $
 
 	This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
 	Copyright (C) 2003 - 2006  Tilo Lutz
+	Copyright (C) 2007  Roland Gruber
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,6 +26,7 @@
 * Used to delete accounts from LDAP tree.
 *
 * @author Tilo Lutz
+* @author Roland Gruber
 * @package main
 */
 
@@ -138,77 +140,70 @@ if ($_POST['delete']) {
 		// First load DN.
 		$_SESSION['account']->load_account($_SESSION['delete_dn'][$m]);
 		// get commands and changes of each attribute
-		$module = array_keys ($_SESSION['account']->module);
+		$module = array_keys($_SESSION['account']->module);
 		$attributes = array();
 		$errors = array();
-		// load attributes
-		foreach ($module as $singlemodule) {
-			// load changes
-			$temp = $_SESSION['account']->module[$singlemodule]->delete_attributes();
-			if (is_array($temp)) {
-				// merge changes
-				$DNs = array_keys($temp);
-				// *** fixme don't include references
-				$attributes = array_merge_recursive($temp, $attributes);
-				for ($i=0; $i<count($DNs); $i++) {
-					$ops = array_keys($temp[$DNs[$i]]);
-					for ($j=0; $j<count($ops); $j++) {
-						$attrs = array_keys($temp[$DNs[$i]][$ops[$j]]);
-						for ($k=0; $k<count($attrs); $k++)
-						$attributes[$DNs[$i]][$ops[$j]][$attrs[$k]] = array_unique($attributes[$DNs[$i]][$ops[$j]][$attrs[$k]]);
-					}
-				}
-			}
-		}
-		$DNs = array_keys($attributes);
-		for ($i=0; $i<count($DNs); $i++) {
-			if (isset($attributes[$DNs[$i]]['errors'])) {
-				foreach ($attributes[$DNs[$i]]['errors'] as $singleerror) {
-					$errors[] = $singleerror;
-					if ($singleerror[0] == 'ERROR') $stopprocessing = true;
-				}
-			}
-			if (!$stopprocessing) {
-				// modify attributes
-				if (isset($attributes[$DNs[$i]]['modify']) && !$stopprocessing) {
-					$success = @ldap_mod_replace($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['modify']);
-					if (!$success) {
-						$errors[] = array ('ERROR', sprintf(_('Was unable to modify attribtues from DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
-						$stopprocessing = true;
-					}
-				}
-				// add attributes
-				if (isset($attributes[$DNs[$i]]['add']) && !$stopprocessing) {
-					$success = @ldap_mod_add($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['add']);
-					if (!$success) {
-						$errors[] = array ('ERROR', sprintf(_('Was unable to add attribtues to DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
-						$stopprocessing = true;
-					}
-				}
-				// removce attributes
-				if (isset($attributes[$DNs[$i]]['remove']) && !$stopprocessing) {
-					$success = @ldap_mod_del($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['remove']);
-					if (!$success) {
-						$errors[] = array ('ERROR', sprintf(_('Was unable to remove attribtues from DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
-						$stopprocessing = true;
-					}
-				}
-			}
-		}
+		// predelete actions
 		if (!$stopprocessing) {
-			foreach ($attributes as $DN) {
-				if (is_array($DN['lamdaemon']['command'])) $result = lamdaemon($DN['lamdaemon']['command']);
-				if (!is_array($result)) continue;
-				// check for error somewhere in lamdaemon
-				foreach ($result as $singleresult) {
-					$singleresult = explode(",", $singleresult);
-					if (is_array($singleresult)) {
-						if ($singleresult[0] == 'ERROR') {
+			foreach ($module as $singlemodule) {
+				$success = $_SESSION['account']->module[$singlemodule]->preDeleteActions();
+				if (!$success) {
+					$stopprocessing = true;
+					break;
+				}
+			}
+		}		
+		if (!$stopprocessing) {
+			// load attributes
+			foreach ($module as $singlemodule) {
+				// load changes
+				$temp = $_SESSION['account']->module[$singlemodule]->delete_attributes();
+				if (is_array($temp)) {
+					// merge changes
+					$DNs = array_keys($temp);
+					// *** fixme don't include references
+					$attributes = array_merge_recursive($temp, $attributes);
+					for ($i=0; $i<count($DNs); $i++) {
+						$ops = array_keys($temp[$DNs[$i]]);
+						for ($j=0; $j<count($ops); $j++) {
+							$attrs = array_keys($temp[$DNs[$i]][$ops[$j]]);
+							for ($k=0; $k<count($attrs); $k++)
+							$attributes[$DNs[$i]][$ops[$j]][$attrs[$k]] = array_unique($attributes[$DNs[$i]][$ops[$j]][$attrs[$k]]);
+						}
+					}
+				}
+			}
+			$DNs = array_keys($attributes);
+			for ($i=0; $i<count($DNs); $i++) {
+				if (isset($attributes[$DNs[$i]]['errors'])) {
+					foreach ($attributes[$DNs[$i]]['errors'] as $singleerror) {
+						$errors[] = $singleerror;
+						if ($singleerror[0] == 'ERROR') $stopprocessing = true;
+					}
+				}
+				if (!$stopprocessing) {
+					// modify attributes
+					if (isset($attributes[$DNs[$i]]['modify']) && !$stopprocessing) {
+						$success = @ldap_mod_replace($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['modify']);
+						if (!$success) {
+							$errors[] = array ('ERROR', sprintf(_('Was unable to modify attribtues from DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
+							$stopprocessing = true;
+						}
+					}
+					// add attributes
+					if (isset($attributes[$DNs[$i]]['add']) && !$stopprocessing) {
+						$success = @ldap_mod_add($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['add']);
+						if (!$success) {
+							$errors[] = array ('ERROR', sprintf(_('Was unable to add attribtues to DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
+							$stopprocessing = true;
+						}
+					}
+					// removce attributes
+					if (isset($attributes[$DNs[$i]]['remove']) && !$stopprocessing) {
+						$success = @ldap_mod_del($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['remove']);
+						if (!$success) {
+							$errors[] = array ('ERROR', sprintf(_('Was unable to remove attribtues from DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
 							$stopprocessing = true;
-							$temparray[0] = $singleresult[0];
-							$temparray[1] = $singleresult[1];
-							$temparray[2] = $singleresult[2];
-							$errors[] = $temparray;
 						}
 					}
 				}
@@ -218,6 +213,12 @@ if ($_POST['delete']) {
 			$errors = deleteDN($_SESSION['delete_dn'][$m]);
 			if (sizeof($errors) > 0) $stopprocessing = true;
 		}
+		// post delete actions
+		if (!$stopprocessing) {
+			foreach ($module as $singlemodule) {
+				$_SESSION['account']->module[$singlemodule]->postDeleteActions();
+			}
+		}		
 		if (!$stopprocessing) {
 			echo sprintf(_('Deleted DN: %s'), $_SESSION['delete_dn'][$m]) . "<br>\n";
 			foreach ($errors as $error) StatusMessage($error[0], $error[1], $error[2]);
