@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.97 2006/10/18 16:08:58 gruberroland Exp $
+$Id: login.php,v 1.98 2007/02/11 13:55:03 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -209,7 +209,7 @@ function display_LoginPage($config_object) {
 				<td style="border-style:none" width="70" rowspan="2">
 					<img src="../graphics/lam.png" alt="Logo">
 				</td>
-				<td width="580">
+				<td style="border-style:none" width="580">
 					<form action="login.php" method="post">
 						<table width="580">
 							<tr>
@@ -294,7 +294,7 @@ function display_LoginPage($config_object) {
 				</td>
 			</tr>
 			<tr>
-				<td>
+				<td style="border-style:none">
 					<form action="login.php" method="post">
 						<table width="580">
 							<tr>
