@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massDoUpload.php,v 1.9 2006/03/26 17:51:25 gruberroland Exp $
+$Id: massDoUpload.php,v 1.10 2006/11/28 19:45:30 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -100,7 +100,7 @@ if (($_SESSION['mass_counter'] < sizeof($accounts)) || !isset($_SESSION['mass_po
 			$_SESSION['mass_postActions']['finished'] = true;
 		}
 		for ($i = 0; $i < sizeof($return['errors']); $i++) $_SESSION['mass_errors'][] = $return['errors'][$i];
-		echo "<h1>" . _("Additional tasks for module:") . ' ' . $return['module'] . "</h1>\n";
+		echo "<h1>" . _("Additional tasks for module:") . ' ' . getModuleAlias($return['module'], $_SESSION['mass_scope']) . "</h1>\n";
 		echo "<table align=\"center\" width=\"80%\" style=\"border-color: grey\" border=\"2\" cellspacing=\"0\" rules=\"none\">\n";
 		echo "<tr><td bgcolor=\"blue\" width=\"" . $return['progress'] . "%\">&nbsp;</td>";
 		echo "<td bgcolor=\"grey\" width=\"" . (100 - $return['progress']) . "%\">&nbsp;</td></tr>\n";
